pub struct PcdHeaderBuilder { /* private fields */ }Expand description
Builder for constructing PcdHeader with a fluent API.
Implementations
Sourceimpl PcdHeaderBuilder
impl PcdHeaderBuilder
Sourcepub fn add_field(self, name: &str, value_type: ValueType) -> Self
pub fn add_field(self, name: &str, value_type: ValueType) -> Self
Add a field with the given name and type.
Fields are added in order and can only have count=1.
For fields with count > 1, use add_field_with_count.
Sourcepub fn width(self, w: u32) -> Self
pub fn width(self, w: u32) -> Self
Set the width (number of points per row). For unorganized point clouds, this equals the total number of points.
Sourcepub fn height(self, h: u32) -> Self
pub fn height(self, h: u32) -> Self
Set the height (number of rows). Default is 1 (unorganized point cloud).
Sourcepub fn data_format(self, fmt: DataFormat) -> Self
pub fn data_format(self, fmt: DataFormat) -> Self
Set the data format (Ascii, Binary, or BinaryCompressed). Default is Binary.